package App::ansifold;
use 5.014;
use strict;
use warnings;

use Exporter 'import';
our @EXPORT_OK = qw($VERSION);

our $VERSION = "1.01";

1;
__END__

=head1 NAME

App::ansifold - fold command handling ANSI terminal sequences

=head1 LICENSE

Copyright (C) Kazumasa Utashiro.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 AUTHOR

Kazumasa Utashiro

=cut
